@@ -10,9 +10,6 @@ from policyengine_core.simulations import (
     IndividualSim as CoreIndividualSim,
 )
 from policyengine_us.data import DATASETS, CPS_2023
-from policyengine_us.tools.taxcalc.generate_taxcalc_variable import (
-    add_taxcalc_variable_aliases,
-)
 from policyengine_us.variables.household.demographic.geographic.state.in_state import (
     create_50_state_variables,
 )
@@ -21,6 +18,9 @@ from policyengine_us.reforms import create_structural_reforms_from_parameters
 
 COUNTRY_DIR = Path(__file__).parent
 
+CURRENT_YEAR = 2023
+year_start = str(CURRENT_YEAR) + "-01-01"
+
 
 class CountryTaxBenefitSystem(TaxBenefitSystem):
     parameters_dir = COUNTRY_DIR / "parameters"
@@ -33,22 +33,21 @@ class CountryTaxBenefitSystem(TaxBenefitSystem):
     ]
     modelled_policies = COUNTRY_DIR / "modelled_policies.yaml"
 
-    def __init__(self):
-        # We initialize our tax and benefit system with the general constructor
-        super().__init__(entities)
+    def __init__(self, reform=None):
+        super().__init__(entities, reform=reform)
 
         reform = create_structural_reforms_from_parameters(
-            self.parameters, "2023-01-01"
+            self.parameters, year_start
         )
         if reform is not None:
-            self.apply_reform(reform)
+            reform.apply(self)
 
         self.add_variables(*create_50_state_variables())
 
         self.parameters = set_irs_uprating_parameter(self.parameters)
-        self.parameters = backdate_parameters(self.parameters)
-
-        add_taxcalc_variable_aliases(self)
+        self.parameters = backdate_parameters(
+            self.parameters, first_instant="2020-01-01"
+        )
 
 
 system = CountryTaxBenefitSystem()
@@ -58,15 +57,15 @@ class Simulation(CoreSimulation):
     default_tax_benefit_system = CountryTaxBenefitSystem
     default_tax_benefit_system_instance = system
     default_role = "member"
-    default_calculation_period = 2022
-    default_input_period = 2022
+    default_calculation_period = CURRENT_YEAR
+    default_input_period = CURRENT_YEAR
     datasets = DATASETS
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
         reform = create_structural_reforms_from_parameters(
-            self.tax_benefit_system.parameters, "2023-01-01"
+            self.tax_benefit_system.parameters, year_start
         )
         if reform is not None:
             self.apply_reform(reform)
@@ -76,17 +75,17 @@ class Microsimulation(CoreMicrosimulation):
     default_tax_benefit_system = CountryTaxBenefitSystem
     default_tax_benefit_system_instance = system
     default_dataset = CPS_2023
-    default_dataset_year = 2023
+    default_dataset_year = CURRENT_YEAR
     default_role = "member"
-    default_calculation_period = 2023
-    default_input_period = 2023
+    default_calculation_period = CURRENT_YEAR
+    default_input_period = CURRENT_YEAR
     datasets = DATASETS
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
         reform = create_structural_reforms_from_parameters(
-            self.tax_benefit_system.parameters, "2023-01-01"
+            self.tax_benefit_system.parameters, year_start
         )
         if reform is not None:
             self.apply_reform(reform)
