@@ -8,15 +8,15 @@ class taxsim_mstat(Variable):
     definition_period = YEAR
 
     def formula(tax_unit, period, parameters):
-        marital_status = tax_unit("mars", period)
-        marital = marital_status.possible_values
+        filing_status = tax_unit("filing_status", period)
+        fstatus = filing_status.possible_values
         return select(
             [
-                marital_status == marital.SINGLE,
-                marital_status == marital.HEAD_OF_HOUSEHOLD,
-                marital_status == marital.JOINT,
-                marital_status == marital.SEPARATE,
-                marital_status == marital.WIDOW,
+                filing_status == fstatus.SINGLE,
+                filing_status == fstatus.HEAD_OF_HOUSEHOLD,
+                filing_status == fstatus.JOINT,
+                filing_status == fstatus.SEPARATE,
+                filing_status == fstatus.WIDOW,
             ],
             [
                 1,
