@@ -10,6 +10,8 @@ class ky_income_tax_before_refundable_credits(Variable):
     defined_for = StateCode.KY
 
     def formula(tax_unit, period, paramters):
-        income = tax_unit("ky_taxable_income", period)
-        rate = paramters(period).gov.states.ky.tax.income.rate
-        return income * rate
+        tax_before_non_refundable = tax_unit(
+            "ky_income_tax_before_non_refundable_credits", period
+        )
+        non_refundable_credits = tax_unit("ky_non_refundable_credits", period)
+        return max_(tax_before_non_refundable - non_refundable_credits, 0)
