@@ -10,6 +10,6 @@ class nh_income_tax_before_refundable_credits(Variable):
     defined_for = StateCode.NH
 
     def formula(tax_unit, period, parameters):
-        income = tax_unit("nh_taxable_income", period)
-        rate = parameters(period).gov.states.nh.tax.income.main
+        income = max_(0, tax_unit("nh_taxable_income", period))
+        rate = parameters(period).gov.states.nh.tax.income.rate
         return income * rate
