@@ -3,9 +3,9 @@ from policyengine_us.model_api import *
 
 class nj_agi_additions(Variable):
     value_type = float
-    entity = TaxUnit
-    label = "New Jersey AGI additions"
+    entity = Person
+    label = "New Jersey additions to federal AGI by person"
     unit = USD
-    documentation = "Additions to NJ AGI over federal AGI."
+    documentation = "Additions to federal AGI to get NJ total income."
     definition_period = YEAR
     reference = "https://law.justia.com/codes/new-jersey/2022/title-54/section-54-8a-36/"
