@@ -15,6 +15,6 @@ class oh_eitc(Variable):
     defined_for = StateCode.OH
 
     def formula(tax_unit, period, parameters):
-        federal_eitc = tax_unit("earned_income_tax_credit", period)
-        rate = parameters(period).gov.states.oh.tax.income.credits.eitc.rate
-        return federal_eitc * rate
+        federal_eitc = tax_unit("eitc", period)
+        match = parameters(period).gov.states.oh.tax.income.credits.eitc.rate
+        return federal_eitc * match
