@@ -8,18 +8,28 @@ class state_income_tax_before_refundable_credits(Variable):
     unit = USD
     definition_period = YEAR
     adds = [
+        "co_income_tax_before_refundable_credits",
+        "dc_income_tax_before_refundable_credits",
+        "de_income_tax_before_refundable_credits",
         "ia_income_tax_before_refundable_credits",
         "il_total_tax",
+        "in_income_tax_before_refundable_credits",
         "ks_income_tax_before_refundable_credits",
         "ma_income_tax_before_refundable_credits",
         "md_income_tax_before_refundable_credits",
         "me_income_tax_before_refundable_credits",
         "mn_income_tax_before_refundable_credits",
         "mo_income_tax_before_refundable_credits",
+        "nc_income_tax",  # NC has no refundable credits.
         "nd_income_tax_before_refundable_credits",
         "ne_income_tax_before_refundable_credits",
+        "nh_income_tax_before_refundable_credits",
+        "nj_income_tax_before_refundable_credits",
+        "nm_income_tax_before_refundable_credits",
         "ny_income_tax_before_refundable_credits",
         "or_income_tax_before_refundable_credits",
         "pa_income_tax",  # PA has no refundable credits.
+        "vt_income_tax_before_refundable_credits",
         "wa_income_tax_before_refundable_credits",
+        "wi_income_tax_before_refundable_credits",
     ]
