@@ -4,7 +4,7 @@ from policyengine_us.model_api import *
 class snap_min_allotment(Variable):
     value_type = float
     entity = SPMUnit
-    definition_period = YEAR
+    definition_period = MONTH
     label = "SNAP minimum allotment"
     documentation = (
         "Minimum allotment for SNAP based on household size and state"
@@ -18,12 +18,9 @@ class snap_min_allotment(Variable):
         # Calculate the relevant maximum benefit, defined as the maximum
         # benefit for a household of a certain size in their state.
         snap_region = spm_unit.household("snap_region_str", period)
-        relevant_max_allotment = (
-            snap.max_allotment.main[snap_region][
-                str(min_allotment.relevant_max_allotment_household_size)
-            ]
-            * MONTHS_IN_YEAR
-        )
+        relevant_max_allotment = snap.max_allotment.main[snap_region][
+            str(min_allotment.relevant_max_allotment_household_size)
+        ]
         # Minimum benefits only apply to households up to a certain size.
         size = spm_unit("spm_unit_size", period)
         eligible = size <= min_allotment.maximum_household_size
