@@ -10,22 +10,34 @@ class household_refundable_tax_credits(Variable):
     adds = [
         "income_tax_refundable_credits",  # Federal.
         "ca_refundable_credits",  # California.
+        "co_refundable_credits",  # Colorado.
+        "dc_refundable_credits",  # District of Columbia.
+        "de_refundable_credits",  # Delaware.
         "ia_refundable_credits",  # Iowa.
         "il_refundable_credits",  # Illinois.
+        "in_refundable_credits",  # Indiana.
         "ks_refundable_credits",  # Kansas.
-        "me_refundable_credits",  # Maine.
         "ma_refundable_credits",  # Massachusetts.
+        "me_refundable_credits",  # Maine.
         "md_refundable_credits",  # Maryland.
         "mn_refundable_credits",  # Minnesota.
         "mo_refundable_credits",  # Missouri.
-        "or_refundable_credits",  # Oregon.
+        # Skip NC, which has no refundable credits.
         "nd_refundable_credits",  # North Dakota.
         "ne_refundable_credits",  # Nebraska.
+        "nh_refundable_credits",  # New Hampshire.
+        "nj_refundable_credits",  # New Jersey.
+        "nm_refundable_credits",  # New Mexico.
         "ny_refundable_credits",  # New York.
+        "ok_refundable_credits",  # Oklahoma.
+        "or_refundable_credits",  # Oregon.
         # Skip PA, which has no refundable credits.
         "wa_refundable_credits",  # Washington.
-        "nyc_refundable_credits",  # New York City.
         "ut_refundable_credits",  # Utah.
+        "vt_refundable_credits",  # Vermont.
+        "wi_refundable_credits",  # Wisconsin.
+        # LOCAL
+        "nyc_refundable_credits",  # New York City.
     ]
 
     def formula(household, period, parameters):
