@@ -4,9 +4,9 @@ from policyengine_us.model_api import *
 class short_term_capital_gains(Variable):
     value_type = float
     entity = Person
-    label = "Short-term capital gains"
+    label = "short-term capital gains"
     unit = USD
-    documentation = "The sum of all gains made from (profitable) sales of assets held for one year or less."
+    documentation = "Net gains made from sales of assets held for one year or less(losses are expressed as negative gains)."
     definition_period = YEAR
     reference = dict(
         title="26 U.S. Code § 1222(1)",
