@@ -4,6 +4,6 @@ from policyengine_us.model_api import *
 class partnership_s_corp_income(Variable):
     value_type = float
     entity = Person
-    label = "Partnership/S-corp income"
+    label = "partnership/S-corp income"
     unit = USD
     definition_period = YEAR
